@@ -15,6 +15,6 @@
 #' }
 `cr_r` <- function(sample = 10, ...) {
   tmp <- cr_works(sample = sample, ...)
-  dois <- suppressWarnings(tryCatch(tmp$data$DOI, error = function(e) e))
+  dois <- suppressWarnings(tryCatch(tmp$data$doi, error = function(e) e))
   if (inherits(dois, "error")) NULL else dois
 }
